<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Repetir: Tot</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Repetir: Canço</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">Reproduint.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">Carregant reproducció.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Reproducció pausada.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Error de sortida.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Reproducció parada.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Reproducció finalitzada.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Error de decodificació.</translation>
    </message>
</context>
<context>
    <name>DatabaseBox</name>
    <message>
        <source>Select music to be played:</source>
        <translation type="obsolete">Escull la música a escoltar:</translation>
    </message>
    <message>
        <source>Copy To New Playlist</source>
        <translation>Copiar a una nova llista de reproducció</translation>
    </message>
    <message>
        <source>Clear the Active Play Queue</source>
        <translation>Esborrar la llista a escoltar activa</translation>
    </message>
    <message>
        <source>Save Back to Playlist Tree</source>
        <translation>Guardar la llista</translation>
    </message>
    <message>
        <source>Move to Active Play Queue</source>
        <translation>Posar a la cua de llista de reproducció</translation>
    </message>
    <message>
        <source>Delete This Playlist</source>
        <translation>Esborrar aquesta llista de reproducció</translation>
    </message>
    <message>
        <source>Rename This Playlist</source>
        <translation>Canviar de nom la llista</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Activar la cua de llistes</translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Totes les llistes</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Tota la música</translation>
    </message>
    <message>
        <source>Blechy Blech Blah</source>
        <translation>Bla bla bla</translation>
    </message>
    <message>
        <source>All My Music ~ Loading Music Data </source>
        <translation>Tota la música ~ Carregant les dades</translation>
    </message>
    <message>
        <source>Loading Music Data</source>
        <translation>Carregant la base de dades de música</translation>
    </message>
    <message>
        <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t create CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-RW Blanking Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Audio CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create MP3 CD from Playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear CD-RW Disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation type="unfinished">Gènere: </translation>
    </message>
    <message>
        <source>Compilation Artist:<byte value="x9"/></source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DB Statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation type="unfinished">Varis artistes</translation>
    </message>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Compilation Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to Database Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save to File and Database</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit/Do Not Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to save the modified metadata to the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlaybackBox</name>
    <message>
        <source>Shuffle Mode</source>
        <translation type="obsolete">Mode aleatori</translation>
    </message>
    <message>
        <source>Repeat Mode</source>
        <translation type="obsolete">Mode repetir</translation>
    </message>
    <message>
        <source>Edit Playlist</source>
        <translation type="obsolete">Editar la llista</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="obsolete">Visualitzar</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">Puntuació</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="obsolete">Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="obsolete">Títol</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Duració</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="obsolete">Repetir: Pista</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="obsolete">Repetir: Tot</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="obsolete">Reproduint.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="obsolete">Carregant reproducció.</translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="obsolete">Reproducció en pausa.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="obsolete">Error de sortida.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="obsolete">Reproducció parada.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="obsolete">Reproducció finalitzada.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="obsolete">Error de decodificació.</translation>
    </message>
    <message>
        <source>Shuffle: Intelligent</source>
        <translation type="obsolete">Aleat.: Intel·ligent</translation>
    </message>
    <message>
        <source>Shuffle: Random</source>
        <translation type="obsolete">Aleatori: Casual</translation>
    </message>
    <message>
        <source>1 Shuffle: Intelligent</source>
        <translation type="obsolete">1 Aleat.: Intel·ligent</translation>
    </message>
    <message>
        <source>1 Shuffle: Random</source>
        <translation type="obsolete">1 Aleatori: Casual</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="obsolete">1 Aleatori: No</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="obsolete">Aleatori: No</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="obsolete">2 Repetir: Tot</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="obsolete">2 Repetir: Pista</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="obsolete">2 Reperir: No</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="obsolete">Repetir: No</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="obsolete">3 Editar Llista</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="obsolete">4 Visualitzar</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="obsolete">1 Aleatori: Preferit</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="obsolete">Aleatori: Preferit</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="obsolete">1 Aleatori: Variable</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="obsolete">Aleatori: Variable</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="obsolete">Llista arrel</translation>
    </message>
</context>
<context>
    <name>PlaybackBoxMusic</name>
    <message>
        <source>Edit Playlist</source>
        <translation type="unfinished">Editar la llista</translation>
    </message>
    <message>
        <source>Visualize</source>
        <translation type="unfinished">Visualitzar</translation>
    </message>
    <message>
        <source>3 Edit Playlist</source>
        <translation type="unfinished">3 Editar Llista</translation>
    </message>
    <message>
        <source>4 Visualize</source>
        <translation type="unfinished">4 Visualitzar</translation>
    </message>
    <message>
        <source>1 Shuffle: Smart</source>
        <translation type="unfinished">1 Aleatori: Preferit</translation>
    </message>
    <message>
        <source>Shuffle: Smart</source>
        <translation type="unfinished">Aleatori: Preferit</translation>
    </message>
    <message>
        <source>1 Shuffle: Rand</source>
        <translation type="unfinished">1 Aleatori: Variable</translation>
    </message>
    <message>
        <source>Shuffle: Rand</source>
        <translation type="unfinished">Aleatori: Variable</translation>
    </message>
    <message>
        <source>1 Shuffle: None</source>
        <translation type="unfinished">1 Aleatori: No</translation>
    </message>
    <message>
        <source>Shuffle: None</source>
        <translation type="unfinished">Aleatori: No</translation>
    </message>
    <message>
        <source>2 Repeat: All</source>
        <translation type="unfinished">2 Repetir: Tot</translation>
    </message>
    <message>
        <source>Repeat: All</source>
        <translation type="unfinished">Repetir: Tot</translation>
    </message>
    <message>
        <source>2 Repeat: Track</source>
        <translation type="unfinished">2 Repetir: Pista</translation>
    </message>
    <message>
        <source>2 Repeat: None</source>
        <translation type="unfinished">2 Reperir: No</translation>
    </message>
    <message>
        <source>Repeat: None</source>
        <translation type="unfinished">Repetir: No</translation>
    </message>
    <message>
        <source>playlist root</source>
        <translation type="unfinished">Llista arrel</translation>
    </message>
    <message>
        <source>Playing stream.</source>
        <translation type="unfinished">Reproduint.</translation>
    </message>
    <message>
        <source>Buffering stream.</source>
        <translation type="unfinished">Carregant reproducció.</translation>
    </message>
    <message>
        <source>Output error.</source>
        <translation type="unfinished">Error de sortida.</translation>
    </message>
    <message>
        <source>Stream stopped.</source>
        <translation type="unfinished">Reproducció parada.</translation>
    </message>
    <message>
        <source>Finished playing stream.</source>
        <translation type="unfinished">Reproducció finalitzada.</translation>
    </message>
    <message>
        <source>Decoder error.</source>
        <translation type="unfinished">Error de decodificació.</translation>
    </message>
    <message>
        <source>Repeat: Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream paused.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>kHz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks by current Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks from current Year</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Searching for music files</source>
        <translation>Cercant arxius de música</translation>
    </message>
    <message>
        <source>Updating music database</source>
        <translation>Actualitzant la base de dades de música</translation>
    </message>
    <message>
        <source>BumpScope</source>
        <translation></translation>
    </message>
    <message>
        <source>Various Artists</source>
        <translation>Varis artistes</translation>
    </message>
    <message>
        <source>Ogg Vorbis Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Desconegut</translation>
    </message>
    <message>
        <source>FLAC Audio</source>
        <translation></translation>
    </message>
    <message>
        <source>Directory to hold music</source>
        <translation>Directori on es guarda la música</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythMusic needs to have write permission to the directory.</source>
        <translation>Aquest directori (carpeta) ha d&apos;existir, i l&apos;usuari que fa servir el MythMusic n&apos;ha de tenir permís d&apos;escriptura.</translation>
    </message>
    <message>
        <source>Audio device</source>
        <translation>Dispositiu de sò</translation>
    </message>
    <message>
        <source>Audio Device used for playback.</source>
        <translation>Dispositiu de sò durant la reproducció.</translation>
    </message>
    <message>
        <source>CD device</source>
        <translation>Dispositiu de CD</translation>
    </message>
    <message>
        <source>CDRom device used for ripping/playback.</source>
        <translation>CDRom que es farà servir per a la reproducció/volcat.</translation>
    </message>
    <message>
        <source>Tree Sorting</source>
        <translation>Ordenació per arbre</translation>
    </message>
    <message>
        <source>Order in which to sort the Music Selection Tree. Possible values are space-separated list of genre, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the actual directory tree.</source>
        <translation type="obsolete">Ordenació a fer servir en l&apos;arbre de sel·lecció. Es poden fer servir diferents valors separats per espais (genre, artist, album, title o la paraula &quot;directori&quot; per a indicar que l&apos;arbre representa l&apos;arbre de directoris).</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Fitxer de comandes</translation>
    </message>
    <message>
        <source>If present this script will be executed after a CD Rip is completed.</source>
        <translation>Si es trova present, s&apos;executa al finalitzar un volcat de CD.</translation>
    </message>
    <message>
        <source>Filename Format</source>
        <translation>Format del nom de fitxer</translation>
    </message>
    <message>
        <source>Directory and filename Format used to grab information if no ID3 information is found.</source>
        <translation>El directori i el nom de fitxer són util·litzats quan no hi ha informació ID3.</translation>
    </message>
    <message>
        <source>Ignore ID3 Tags</source>
        <translation>Ignorar les marques ID3</translation>
    </message>
    <message>
        <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
        <translation>Si s&apos;activa, MythMusic no comprovarà les marques ID3 dels fitxers i intentarà determinar el Gènere, Artista, Àlbum, Pista i Títol en funció del nom de l&apos;arxiu.</translation>
    </message>
    <message>
        <source>Automatically lookup CDs</source>
        <translation>Automàticament mira els CDs</translation>
    </message>
    <message>
        <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
        <translation>Automàticament mira si hi ha un CD d&apos;àudio i visualitza la seva informació en l&apos;arbre de sel·lecció de música.</translation>
    </message>
    <message>
        <source>Use Keyboard/Remote Accelerated Buttons</source>
        <translation>Dreceres de tecles de comandament</translation>
    </message>
    <message>
        <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
        <translation>Si no s&apos;activa, necessitará les fletxes per a sel·leccionar i activar vàries funcions.</translation>
    </message>
    <message>
        <source>Encoding</source>
        <translation>Codificació</translation>
    </message>
    <message>
        <source>Ogg Vorbis</source>
        <translation></translation>
    </message>
    <message>
        <source>Lame (MP3)</source>
        <translation></translation>
    </message>
    <message>
        <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
        <translation>Còdec d&apos;àudio per al volcat de CD. El nivell &apos;Perfecte&apos; util.litzarà el còdec FLAC.</translation>
    </message>
    <message>
        <source>File storage location</source>
        <translation>On es guarden els arxius</translation>
    </message>
    <message>
        <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
        <translation>Defineix la carpeta/nom per a les noves cançons. GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / i - són valors vàlids. &apos;-&apos; serà substituït pel caràcter separador</translation>
    </message>
    <message>
        <source>Token separator</source>
        <translation>Caràcter separador</translation>
    </message>
    <message>
        <source> - </source>
        <translation></translation>
    </message>
    <message>
        <source>Filename tokens will be separated by this string.</source>
        <translation>Els noms dels arxius seràn separats per aquesta marca.</translation>
    </message>
    <message>
        <source>Replace &apos; &apos; with &apos;_&apos;</source>
        <translation>Substitueix &apos; &apos; amb &apos;_&apos;</translation>
    </message>
    <message>
        <source>If set, whitespace characters in filenames will be replaced with underscore characters.</source>
        <translation>Quan està actiu, els blancs en els noms dels arxius es substitueixen pel subratllat.</translation>
    </message>
    <message>
        <source>Paranoia Level</source>
        <translation>Nivell de Paranoia</translation>
    </message>
    <message>
        <source>Full</source>
        <translation>Complert</translation>
    </message>
    <message>
        <source>Faster</source>
        <translation>Rápid</translation>
    </message>
    <message>
        <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
        <translation>Nivell Paranoia del volcador de CD. Si no li preocupen els errors en els volcats, posi el rápid.</translation>
    </message>
    <message>
        <source>Automatically eject CDs after ripping</source>
        <translation>Expulsa automàticament el CD després del volcat</translation>
    </message>
    <message>
        <source>If set, the CD tray will automatically open after the CD has been ripped.</source>
        <translation>Quan s&apos;activa, el CD s&apos;expulsa automàticament quan finalitza el volcat.</translation>
    </message>
    <message>
        <source>Rating Weight</source>
        <translation>Pes de puntuació</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to your rating of a given track when ordering a group of songs.</source>
        <translation>Es fa servir en la reproducció segons &quot;Preferit&quot;. És el pès assignat en el moment d&apos;ordenar grups de cançons.</translation>
    </message>
    <message>
        <source>Play Count Weight</source>
        <translation>Pes del comptador de reproduccions</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
        <translation>En el mode de reproducció &apos;Preferit&apos;. Aquest valor afecta a la puntuació atorgada segons el nombre de reproduccions de la cançó.</translation>
    </message>
    <message>
        <source>Last Play Weight</source>
        <translation>Pes per la última reproducció</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
        <translation>En el mode de reproducció &apos;Preferit&apos;. Aquest valor puntúa segons el temps que fa que ha estat reproduida la cançó.</translation>
    </message>
    <message>
        <source>Random Weight</source>
        <translation>Puntuació aleatoria</translation>
    </message>
    <message>
        <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
        <translation>En el mode de reproducció &apos;Preferit&apos;. Aquest valor és el que s&apos;assigna al reproduïr aleatòriament les cançons.</translation>
    </message>
    <message>
        <source>Show Song Ratings</source>
        <translation>Visualitzar puntuacions</translation>
    </message>
    <message>
        <source>Show song ratings on the playback screen.</source>
        <translation>Visualitzar puntuacions en la pantalla de reproducció.</translation>
    </message>
    <message>
        <source>List as Shuffled</source>
        <translation>Llista barrejat</translation>
    </message>
    <message>
        <source>List songs on the playback screen in the order they will be played.</source>
        <translation>Llistar les cançons en l&apos;ordre que seran reproduides.</translation>
    </message>
    <message>
        <source>Show entire music tree</source>
        <translation>Visualitzar l&apos;arbre complert</translation>
    </message>
    <message>
        <source>If selected, you can navigate your entire music tree from the playing screen.</source>
        <translation>Si es trova actiu, podrà navegar per tot l&apos;arbre des de la pantalla de reproducció.</translation>
    </message>
    <message>
        <source>Play mode</source>
        <translation>Mode de reproducció</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation></translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aleatori</translation>
    </message>
    <message>
        <source>Intelligent</source>
        <translation>Intel·ligent</translation>
    </message>
    <message>
        <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
        <translation>Mode inicial del reproductor: Pot ser normal, aleatori o intel·ligent.</translation>
    </message>
    <message>
        <source>Delay before Visualizations start (seconds)</source>
        <translation>Espera avans d&apos;iniciar les visualitzacions (segons)</translation>
    </message>
    <message>
        <source>If set to 0, visualizations will never automatically start.</source>
        <translation>So s&apos;hi posa 0, les visualitzacions no s&apos;inicien mai.</translation>
    </message>
    <message>
        <source>Change Visualizer on each song</source>
        <translation>Canviar la visualització en cada cançó</translation>
    </message>
    <message>
        <source>Change the visualizer when the song change.</source>
        <translation>Canviar la visualitzación quan una cançó canvii.</translation>
    </message>
    <message>
        <source>Width for Visual Scaling</source>
        <translation>Amplada per la visualització</translation>
    </message>
    <message>
        <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
        <translation>Amb valor &quot;2&quot; les visualtzacions són redimensionades a la meitat. Disponible només amb la visualització &apos;goom&apos;. Redueix l&apos;ús de processador en sistemes antics i lents.</translation>
    </message>
    <message>
        <source>Height for Visual Scaling</source>
        <translation>Alçada de la visualització</translation>
    </message>
    <message>
        <source>Visualizations</source>
        <translation>Visualitzacions</translation>
    </message>
    <message>
        <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
        <translation>Llista de visualitzacións durant la reproducció. Els valors possibles s&apos;especifiquen separats per espais en blanc de </translation>
    </message>
    <message>
        <source>MonoScope</source>
        <translation></translation>
    </message>
    <message>
        <source>StereoScope</source>
        <translation></translation>
    </message>
    <message>
        <source>Spectrum</source>
        <translation></translation>
    </message>
    <message>
        <source>Goom</source>
        <translation></translation>
    </message>
    <message>
        <source>Synaesthesia</source>
        <translation></translation>
    </message>
    <message>
        <source>Gears</source>
        <translation></translation>
    </message>
    <message>
        <source>Blank</source>
        <translation></translation>
    </message>
    <message>
        <source>Default Rip Quality</source>
        <translation>Qualitat de volcat per omisió</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecte</translation>
    </message>
    <message>
        <source>Default quality for new CD rips.</source>
        <translation>Qualitat de volcat per a CDs nous.</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Configuració General</translation>
    </message>
    <message>
        <source>Playback Settings</source>
        <translation>Configuració de Reproducció</translation>
    </message>
    <message>
        <source>Visualization Settings</source>
        <translation>Configuració de visualització</translation>
    </message>
    <message>
        <source>CD Ripper Settings</source>
        <translation>Configuració de volcat</translation>
    </message>
    <message>
        <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
        <translation></translation>
    </message>
    <message>
        <source>music database</source>
        <translation type="obsolete">Base de dades de música</translation>
    </message>
    <message>
        <source>cd ripper</source>
        <translation type="obsolete">volcador de CD</translation>
    </message>
    <message>
        <source>

You have no MythMusic tables in your database.</source>
        <translation type="obsolete">

No disposa de les taules de MythMusic en la seva Base de Dades.</translation>
    </message>
    <message>
        <source>OK, I&apos;ll read the documentation</source>
        <translation type="obsolete">OK, llegiré la documentació</translation>
    </message>
    <message>
        <source>Unknown Artist</source>
        <translation>Artista desconegut</translation>
    </message>
    <message>
        <source>Unknown Album</source>
        <translation>Àlbum desconegut</translation>
    </message>
    <message>
        <source>Unknown Genre</source>
        <translation>Gènere desconegut</translation>
    </message>
    <message>
        <source>CD -- none</source>
        <translation>CD - cap CD</translation>
    </message>
    <message>
        <source>All My Music</source>
        <translation>Tota la música</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>title</source>
        <translation>títol</translation>
    </message>
    <message>
        <source>Missing database entry: %1</source>
        <translation>Falta entrada a la basde de dades: %1</translation>
    </message>
    <message>
        <source> ~ </source>
        <translation></translation>
    </message>
    <message>
        <source>Ooops</source>
        <translation></translation>
    </message>
    <message>
        <source>%1 ~ %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Not Initialized</source>
        <translation>No inicialitzat</translation>
    </message>
    <message>
        <source>oops</source>
        <translation></translation>
    </message>
    <message>
        <source>,%1</source>
        <translation></translation>
    </message>
    <message>
        <source>All My Playlists</source>
        <translation>Totes les llistes</translation>
    </message>
    <message>
        <source>Active Play Queue</source>
        <translation>Llista de reproducció activa</translation>
    </message>
    <message>
        <source>Active Play Queue (%1)</source>
        <translation>Llista de reproducció activa (%1)</translation>
    </message>
    <message>
        <source>Something is Wrong</source>
        <translation>Alguna cosa va malament</translation>
    </message>
    <message>
        <source>Visualization requires FFT library</source>
        <translation>La visualització requereix la llibreria FFT</translation>
    </message>
    <message>
        <source>Did you run configure?</source>
        <translation>Ha executat configure?</translation>
    </message>
    <message>
        <source>and</source>
        <translation> i </translation>
    </message>
    <message>
        <source>Use variable bitrates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AlbumArt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Ripper Settings (part 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable CD Writing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD-Writer Device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disk Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>650MB/75min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>700MB/80min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default CD Capacity.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable directories on MP3 Creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Write Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Writer speed. Auto will use the recomended speed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Blanking Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blanking Method. Fast takes 1 minute. Complete can take up to 20 minutes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD Recording Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Creating CD File System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Burning CD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CD: %1 ~ %2 - %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Ripper</name>
    <message>
        <source>Please select a quality level and check the album information below:</source>
        <translation>Esculli el nivell de qualitat i comprovi la informació de l&apos;àlbum:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <source>Perfect</source>
        <translation>Perfecte</translation>
    </message>
    <message>
        <source>Artist: </source>
        <translation>Artista:</translation>
    </message>
    <message>
        <source>Album: </source>
        <translation>Àlbum:</translation>
    </message>
    <message>
        <source>Import this CD</source>
        <translation>Importar aquest CD</translation>
    </message>
    <message>
        <source>Importing CD:
</source>
        <translation>Important CD:
</translation>
    </message>
    <message>
        <source>Copying from CD:
</source>
        <translation>Copiant des del CD:
</translation>
    </message>
    <message>
        <source>Genre: </source>
        <translation>Gènere: </translation>
    </message>
    <message>
        <source>Ripping...</source>
        <translation>Volcant...</translation>
    </message>
    <message>
        <source>Multi-Artist?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Titles &amp;&amp; Artists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Títol</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished">Duració</translation>
    </message>
</context>
<context>
    <name>SmartPLCriteriaRow</name>
    <message>
        <source>Select an Artist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a Title</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLOrderByDialog</name>
    <message>
        <source>Order By Fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6 Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPLResultViewer</name>
    <message>
        <source>Smart Playlist Result Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Títol</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistDialog</name>
    <message>
        <source>Smart Playlists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this SmartPlaylist?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SmartPlaylistEditor</name>
    <message>
        <source>Smart Playlist Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Of The Following Conditions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order By:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matches:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Limit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smart Playlist Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this Category?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It will also delete any Smart Playlists belonging to this category.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Please Wait...</source>
        <translation>Esperi uns moments...</translation>
    </message>
    <message>
        <source>Track Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Album:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track No.:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Count:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Play:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compilation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
